import logging
import os

import coloredlogs

from . import lib


def get_log(name: str, default_level: str = None) -> logging.Logger:
    log = logging.getLogger(name)
    fields = [
        "{name}:{lineno}",
        "+{relativeCreated:,.0f} ms",
        "{message}",
    ]
    coloredlogs.install(
        fmt=" ".join(fields),
        style="{",
        level=default_level or lib.level_from_envar(),
        logger=log,
    )

    return log


if lib.LOG_LEVEL_ENVAR_NAME not in os.environ:
    _log = get_log(__name__)
    _log.info(
        f"To change log levels, set the environment variable LOG_LEVEL to one of: "
        + ", ".join(coloredlogs.find_defined_levels())
    )



import os

import coloredlogs

DEFAULT_LEVEL = "DEBUG"
LOG_LEVEL_ENVAR_NAME = "LOG_LEVEL"


def level_from_envar():
    """
    Read log level from environment variable.
    """
    level = os.environ.get(LOG_LEVEL_ENVAR_NAME)
    if level not in coloredlogs.find_defined_levels():
        level = DEFAULT_LEVEL
    return level



from pathlib import Path

from setuptools import find_packages, setup

setup(
    name="metovlogs",
    version="0.1.6",
    description="Dead simple Python logging.",
    url="https://github.com/metov/metovlogs",
    long_description=Path("README.md").read_text(),
    long_description_content_type="text/markdown",
    author="Azat Akhmetov",
    author_email="azatinfo@yandex.com",
    classifiers=[
        "Programming Language :: Python :: 3",
        "Development Status :: 3 - Alpha",
        "License :: OSI Approved :: MIT License",
    ],
    packages=find_packages(),
    install_requires=["coloredlogs"],
)
